Crate repose_render_wgpu

Crate repose_render_wgpu 

Modules

offscreen
Unified offscreen helper (native/android/wasm).

Structs

Callback
CallbackResources
ScreenDescriptor
WgpuSceneRenderer
WgpuSurfaceBackend

Traits

WgpuCallback
Trait for custom wgpu rendering inside a repose layout rect.

Functions

apply_render_commands
Apply a batch of RenderCommands to a scene renderer.
pick_surface_msaa
Pick the MSAA sample count for the surface pass, honoring requested and falling back to the largest supported count <= it.

Type Aliases

WgpuBackend