pub fn pick_surface_msaa(
adapter: &Adapter,
format: TextureFormat,
requested: u32,
) -> u32Expand description
Pick the MSAA sample count for the surface pass, honoring requested and
falling back to the largest supported count <= it.
pub fn pick_surface_msaa(
adapter: &Adapter,
format: TextureFormat,
requested: u32,
) -> u32Pick the MSAA sample count for the surface pass, honoring requested and
falling back to the largest supported count <= it.