pub struct WgpuSceneRenderer {
pub device: Device,
pub queue: Queue,
pub output_format: TextureFormat,
pub output_width: u32,
pub output_height: u32,
/* private fields */
}Fields
device: Devicequeue: Queueoutput_format: TextureFormatoutput_width: u32output_height: u32Implementations
Sourceimpl WgpuSceneRenderer
impl WgpuSceneRenderer
pub fn from_device( device: Device, queue: Queue, output_format: TextureFormat, msaa_samples: u32, ) -> Self
Sourceimpl WgpuSceneRenderer
impl WgpuSceneRenderer
pub fn set_image_from_bytes( &mut self, handle: u64, data: &[u8], srgb: bool, ) -> Result<()>
pub fn set_image_rgba8( &mut self, handle: u64, w: u32, h: u32, rgba: &[u8], srgb: bool, ) -> Result<()>
pub fn set_image_nv12( &mut self, handle: u64, w: u32, h: u32, y: &[u8], uv: &[u8], color_info: ColorInfo, ) -> Result<()>
pub fn set_image_planes( &mut self, handle: u64, w: u32, h: u32, pixel_format: PixelFormat, planes: &[&[u8]], color_info: ColorInfo, ) -> Result<()>
pub fn set_image_dmabuf( &mut self, handle: u64, w: u32, h: u32, fds: Vec<OwnedFd>, modifier: u64, strides: Vec<u32>, offsets: Vec<u64>, color_info: ColorInfo, ) -> Result<()>
pub fn remove_image(&mut self, handle: u64)
pub fn register_image_from_bytes(&mut self, data: &[u8], srgb: bool) -> u64
Sourcepub fn set_working_space(&mut self, enabled: bool)
pub fn set_working_space(&mut self, enabled: bool)
Enable or disable linear working-space rendering. When enabled, the scene is rendered into an Rgba16Float intermediate and a final full-screen pass applies the display OETF.
Sourceimpl WgpuSceneRenderer
impl WgpuSceneRenderer
pub fn render_scene_to_encoder( &mut self, scene: &Scene, encoder: &mut CommandEncoder, target_view: &TextureView, clear_color_override: Option<[f64; 4]>, )
Sourcepub fn render_to_view(
&mut self,
scene: &Scene,
encoder: &mut CommandEncoder,
target_view: &TextureView,
width: u32,
height: u32,
clear_color: Option<[f64; 4]>,
)
pub fn render_to_view( &mut self, scene: &Scene, encoder: &mut CommandEncoder, target_view: &TextureView, width: u32, height: u32, clear_color: Option<[f64; 4]>, )
Render a scene into an externally-provided texture view. Use this when embedding Repose in a host that owns the GPU. The host is responsible for submitting the encoder and handling present.