pick_surface_msaa

Function pick_surface_msaa 

pub fn pick_surface_msaa(
    adapter: &Adapter,
    format: TextureFormat,
    requested: u32,
) -> u32
Pick the MSAA sample count for the surface pass, honoring requested and falling back to the largest supported count <= it.